@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.59 2004/09/23 16:01:49 sampie Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.72 2005/07/11 19:23:35 richb Exp $
  *
- *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,8 @@
 #include <stdlib.h>
 #include <locale.h>
 #include <math.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #define MP_SIZE      150     /* Size of the multiple precision values. */
 
@@ -50,7 +51,7 @@
 
 /* Menu bar menu types. */
 
-enum mb_type { M_ABOUT, M_ASCII, M_BASIC, M_CONTENTS, M_COPY,  M_FIN,
+enum mb_type { M_ABOUT, M_ASCII, M_BASIC, M_ADV, M_CONTENTS, M_COPY,  M_FIN,
 	       M_PASTE, M_QUIT,  M_REGS,  M_SCI, M_EXP, M_TSEP, M_ZEROES };
 
 enum base_type { BIN, OCT, DEC, HEX };      /* Base definitions. */
@@ -67,42 +68,46 @@ enum menu_type { M_ACC,  M_CON,  M_EXCH, M_FUN,  M_LSHF,
 };
 
 /* Calculator modes. */
-enum mode_type { BASIC, FINANCIAL, SCIENTIFIC };
+enum mode_type { BASIC, ADVANCED, FINANCIAL, SCIENTIFIC };
 
 enum num_type { ENG, FIX, SCI };            /* Number display mode. */
 
 /* Resources. */
 enum res_type { R_ACCURACY, R_BASE, R_DISPLAY, R_MODE, R_REGS, R_TRIG,
-                R_ZEROES,   R_TSEP, R_SYNTAX
+                R_ZEROES,   R_TSEP, R_SYNTAX, 
+                R_REG0,     R_REG1, R_REG2,    R_REG3, R_REG4,
+                R_REG5,     R_REG6, R_REG7,    R_REG8, R_REG9
 };
 
 enum trig_type { DEG, GRAD, RAD };          /* Trigonometric types. */
 
-enum trig_func { SIN=1, COS=2, TAN=4 };
+enum trig_func {SIN=0, COS=1, TAN=2};       
 
 /* Abbreviations for the gcalctool keyboard and menu equivalents. */
 
-#define KEY_DIV   b_buttons[3]              /* / */
-#define KEY_BSP   b_buttons[5]              /* Control-h */
+#define KEY_DIV   a_buttons[3]              /* / */
+#define KEY_LPAR  a_buttons[4]              /* ( */
+#define KEY_BSP   a_buttons[5]              /* Control-h */
 
-#define KEY_MUL   b_buttons[11]             /* * */
+#define KEY_MUL   a_buttons[11]             /* * */
+#define KEY_RPAR  a_buttons[12]             /* ) */
 
-#define KEY_CHS   b_buttons[13]             /* C */
-#define KEY_INT   b_buttons[14]             /* i */
-#define KEY_STO   b_buttons[15]             /* S */
+#define KEY_CHS   a_buttons[13]             /* C */
+#define KEY_INT   a_buttons[14]             /* i */
+#define KEY_STO   a_buttons[15]             /* S */
 
-#define KEY_SUB   b_buttons[19]             /* - */
-#define KEY_PER   b_buttons[20]             /* % */
-#define KEY_SQRT  b_buttons[21]             /* s */
-#define KEY_FRAC  b_buttons[22]             /* : */
-#define KEY_RCL   b_buttons[23]             /* R */
+#define KEY_SUB   a_buttons[19]             /* - */
+#define KEY_PER   a_buttons[20]             /* % */
+#define KEY_SQRT  a_buttons[21]             /* s */
+#define KEY_FRAC  a_buttons[22]             /* : */
+#define KEY_RCL   a_buttons[23]             /* R */
 
-#define KEY_EQ    b_buttons[26]             /* = */
-#define KEY_ADD   b_buttons[27]             /* + */
-#define KEY_REC   b_buttons[28]             /* r */
-#define KEY_SQR   b_buttons[29]             /* @ */
-#define KEY_ABS   b_buttons[30]             /* u */
-#define KEY_EXCH  b_buttons[31]             /* X */
+#define KEY_EQ    a_buttons[26]             /* = */
+#define KEY_ADD   a_buttons[27]             /* + */
+#define KEY_REC   a_buttons[28]             /* r */
+#define KEY_SQR   a_buttons[29]             /* @ */
+#define KEY_ABS   a_buttons[30]             /* u */
+#define KEY_EXCH  a_buttons[31]             /* X */
 
 #define KEY_CTRM  f_buttons[0]              /* m */
 #define KEY_DDB   f_buttons[1]              /* D */
@@ -118,8 +123,6 @@ enum trig_func { SIN=1, COS=2, TAN=4 };
 #define KEY_RSFT  s_buttons[1]              /* > */
 #define KEY_16    s_buttons[2]              /* [ */
 #define KEY_32    s_buttons[3]              /* ] */
-#define KEY_LPAR  s_buttons[5]              /* ( */
-#define KEY_RPAR  s_buttons[6]              /* ) */
 #define KEY_ACC   s_buttons[7]              /* A */
 
 #define KEY_CON   s_buttons[8]              /* # */
@@ -142,8 +145,11 @@ enum trig_func { SIN=1, COS=2, TAN=4 };
 #define KEY_XOR   s_buttons[30]             /* ^ */
 #define KEY_XNOR  s_buttons[31]             /* n */
 
-#define BCOLS          8      /* No of columns of Basic Mode buttons. */
-#define BROWS          4      /* No of rows of Basic Mode buttons. */
+#define BCOLS          4      /* No of columns of Basic Mode buttons. */
+#define BROWS          5      /* No of rows of Basic Mode buttons. */
+
+#define ACOLS          8      /* No of columns of Advanced Mode buttons. */
+#define AROWS          4      /* No of rows of Advanced Mode buttons. */
 
 #define FCOLS          8      /* No of columns of Financial Mode buttons. */
 #define FROWS          2      /* No of rows of Financial Mode buttons. */
@@ -196,6 +202,7 @@ enum trig_func { SIN=1, COS=2, TAN=4 };
 #endif /*MIN*/
 
 #define B_NOBUTTONS      BROWS * BCOLS  /* Number of Basic Mode buttons. */
+#define A_NOBUTTONS      AROWS * ACOLS  /* Number of Advanced Mode buttons. */
 #define F_NOBUTTONS      FROWS * FCOLS  /* Number of Financial Mode buttons. */
 #define S_NOBUTTONS      SROWS * SCOLS  /* Number of Scientific Mode buttons. */
 
@@ -355,6 +362,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int show_zeroes;   /* Set if trailing zeroes should be shown. */
     int started;       /* Set just before window is displayed. */
     int toclear;       /* Indicates if display should be cleared. */
+    int warn_change_mode;    /* Should we warn user when changing modes? */
 };
 
 typedef struct calcVars *Vars;
@@ -373,13 +381,14 @@ struct button *button_for_fc(char);
 struct button *button_for_value(int);
 struct button *copy_button_info(struct button *);
 
+void syntaxdep_show_display();
 char *button_str(int);
 char *convert(char *);
 char *gc_strdup(char *str);
 const char *get_radix();
 char *get_resource(enum res_type);
 const char *get_tsep();
-char *make_number(int *, int, BOOLEAN, BOOLEAN);
+char *make_number(int *, int, BOOLEAN);
 char *set_bool(int);
 
 unsigned short *get_but_data();
@@ -423,12 +432,10 @@ void do_trigtype(enum trig_type);
 void doerr(char *);
 void exp_del();
 void get_constant(int);
-void get_display();
 void get_function(int);
 void get_options(int, char **);
 void grey_buttons(enum base_type);
 void handle_menu_selection(struct button *, int);
-void handle_selection();
 void initialise();
 void init_args();
 void init_frame_sizes();
@@ -456,19 +463,19 @@ void refresh_display();
 void save_pending_values(struct button *);
 void save_resources();
 void set_accuracy_menu_item(int);
-void set_accuracy_toggle(int);
 void set_accuracy_tooltip(int);
 void set_display(char *, int);
 void write_display(char *);
 void set_error_state(int);
 void set_hyp_item(int);
 void set_ins_key();
-void set_item(enum item_type, int);
 void set_inv_item(int);
 void set_mode(enum mode_type);
 void set_title(enum fcp_type, char *);
-void show_ascii_frame();
+void show_change_mode_dialog();
 void show_display(int *);
+void show_error(char *);
+void show_menu();
 void srand48();
 void start_tool();
 void str_replace(char **, char *, char *);
