@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/mp.c,v 1.15 2005/02/07 16:38:58 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/mp.c,v 1.16 2005/04/11 17:38:33 richb Exp $
  *
  *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -1199,7 +1199,7 @@ L10:
     accuracy = v->accuracy;
     v->accuracy = MAX_DIGITS;
     mpcmf(&x[1], tmp);
-    STRCPY(disp, make_number(tmp, v->base, TRUE, FALSE));
+    STRCPY(disp, make_number(tmp, v->base, FALSE));
 
     if (disp[0] == '1') {
         y[ll+1]++;
